GUI Tools
=========

Kite comes with two graphical user interfaces:

1. ``spool`` to handle InSAR displacement scenes :mod:`kite.scene.Scene` and
2. ``talpa`` for interactive modelling of various displacement sources.

.. toctree::
    spool
    talpa
